package MyMaskFormatter;

import java.text.ParseException;

import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.DocumentFilter;
import javax.swing.text.MaskFormatter;

public class MyMaskFormatter extends MaskFormatter {
	private static final long serialVersionUID = 4967188238454402594L;

	private DocumentFilter filter;

	public MyMaskFormatter(String string) throws ParseException {
		super(string);
	}

	@Override
	protected DocumentFilter getDocumentFilter() {
		if (filter == null) {
			filter = new MyDocumentFilter(super.getDocumentFilter());
		}
		return filter;
	}

	public class MyDocumentFilter extends DocumentFilter {
		DocumentFilter delegate;

		MyDocumentFilter(DocumentFilter delegate) {
			this.delegate = delegate;
		}

		@Override
		public void remove(FilterBypass fb, int offset, int length)
				throws BadLocationException {
			delegate.remove(fb, offset, length);
			int sublength = fb.getDocument().getLength() - offset;
			String text = fb.getDocument().getText(offset, sublength);
			text = text.substring(1) + text.charAt(0);
			replace(fb, offset, sublength, text, null);
			getFormattedTextField().setCaretPosition(offset);
		}

		@Override
		public void insertString(FilterBypass fb, int offset, String string,
				AttributeSet attr) throws BadLocationException {
			delegate.insertString(fb, offset, string, attr);
		}

		@Override
		public void replace(FilterBypass fb, int offset, int length,
				String text, AttributeSet attrs) throws BadLocationException {
			delegate.replace(fb, offset, length, text, attrs);
		}
	}

}
